@@ -47,11 +47,11 @@ class AddCdnDomainRequest(RpcRequest):
 	def set_DomainName(self,DomainName):
 		self.add_query_param('DomainName',DomainName)
 
-	def get_SslFlag(self):
-		return self.get_query_params().get('SslFlag')
+	def get_CdnType(self):
+		return self.get_query_params().get('CdnType')
 
-	def set_SslFlag(self,SslFlag):
-		self.add_query_param('SslFlag',SslFlag)
+	def set_CdnType(self,CdnType):
+		self.add_query_param('CdnType',CdnType)
 
 	def get_SourceType(self):
 		return self.get_query_params().get('SourceType')
@@ -59,14 +59,26 @@ class AddCdnDomainRequest(RpcRequest):
 	def set_SourceType(self,SourceType):
 		self.add_query_param('SourceType',SourceType)
 
-	def get_CdnType(self):
-		return self.get_query_params().get('CdnType')
-
-	def set_CdnType(self,CdnType):
-		self.add_query_param('CdnType',CdnType)
-
 	def get_Sources(self):
 		return self.get_query_params().get('Sources')
 
 	def set_Sources(self,Sources):
-		self.add_query_param('Sources',Sources)
\ No newline at end of file
+		self.add_query_param('Sources',Sources)
+
+	def get_SourcePort(self):
+		return self.get_query_params().get('SourcePort')
+
+	def set_SourcePort(self,SourcePort):
+		self.add_query_param('SourcePort',SourcePort)
+
+	def get_ServerCertificate(self):
+		return self.get_query_params().get('ServerCertificate')
+
+	def set_ServerCertificate(self,ServerCertificate):
+		self.add_query_param('ServerCertificate',ServerCertificate)
+
+	def get_PrivateKey(self):
+		return self.get_query_params().get('PrivateKey')
+
+	def set_PrivateKey(self,PrivateKey):
+		self.add_query_param('PrivateKey',PrivateKey)
\ No newline at end of file
